From f2f66c8adabd7916d4d2afabe7f2dcb048e8effb Mon Sep 17 00:00:00 2001
From: zhangyanxian <zhangyanxianmail@163.com>
Date: Wed, 16 Nov 2016 09:59:26 +0000
Subject: [PATCH] Fix spelling mistakes in cover.sh

TrivalFix

Change-Id: Iedc1fc108d090e11d8d942379aa8c32d212d16e1
---
 tools/cover.sh | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/tools/cover.sh b/tools/cover.sh
index 69d46c625d..389884cf75 100755
--- a/tools/cover.sh
+++ b/tools/cover.sh
@@ -23,9 +23,9 @@ show_diff () {
     diff -U 0 $1 $2 | sed 1,2d
 }
 
-# Stash uncommited changes, checkout master and save coverage report
-uncommited=$(git status --porcelain | grep -v "^??")
-[[ -n $uncommited ]] && git stash > /dev/null
+# Stash uncommitted changes, checkout master and save coverage report
+uncommitted=$(git status --porcelain | grep -v "^??")
+[[ -n $uncommitted ]] && git stash > /dev/null
 git checkout HEAD^
 
 baseline_report=$(mktemp -t manila_coverageXXXXXXX)
@@ -33,9 +33,9 @@ find . -type f -name "*.pyc" -delete && python setup.py testr --coverage --testr
 coverage report --ignore-errors > $baseline_report
 baseline_missing=$(awk 'END { print $3 }' $baseline_report)
 
 # Checkout back and unstash uncommited changes (if any)
 git checkout -
-[[ -n $uncommited ]] && git stash pop > /dev/null
+[[ -n $uncommitted ]] && git stash pop > /dev/null
 
 # Generate and save coverage report
 current_report=$(mktemp -t manila_coverageXXXXXXX)
@@ -33,9 +33,9 @@ find . -type f -name "*.pyc" -delete && python setup.py testr --coverage --testr
 baseline_missing=$(awk 'END { print $3 }' $baseline_report)
 
-# Checkout back and unstash uncommited changes (if any)
+# Checkout back and unstash uncommitted changes (if any)
 git checkout -